# This file was auto-generated by Fern from our API Definition.

import typing

Provider = typing.Union[
    typing.Literal[
        "openai", "anthropic", "azure_openai", "google_vertexai", "google_genai", "ollama", "groq", "fireworks"
    ],
    typing.Any,
]
