# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .input import Input
from .runnable_config import RunnableConfig
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class CreateRunPayload(UniversalBaseModel):
    """
    Payload for creating a run.
    """

    thread_id: str
    input: typing.Optional[Input] = None
    config: typing.Optional[RunnableConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
