# This file was auto-generated by Fern from our API Definition.

import typing
from .human_message_content_item import HumanMessageContentItem

Content = typing.Union[str, typing.List[HumanMessageContentItem]]
